using Microsoft.Extensions.DependencyInjection;
using PrecastConcretePlantView;
using RenovationWorkBusinessLogic.BusinessLogic;
using RenovationWorkContracts.BusinessLogicsContracts;
using RenovationWorkContracts.StorageContracts;
using RenovationWorkDatabaseImplement.Implements;
using System;
using Microsoft.Extensions.Logging;
using NLog.Extensions.Logging;
using RenovationWorkBusinessLogic.OfficePackage.Implements;
using RenovationWorkBusinessLogic.OfficePackage;

namespace RenovationWorkView
{
    internal static class Program
    {
        private static ServiceProvider? _serviceProvider;
        public static ServiceProvider? ServiceProvider => _serviceProvider;

        [STAThread]
        static void Main()
        {
            ApplicationConfiguration.Initialize();
            var services = new ServiceCollection();
            ConfigureServices(services);
            _serviceProvider = services.BuildServiceProvider();
            Application.Run(_serviceProvider.GetRequiredService<FormMain>());
        }
        private static void ConfigureServices(ServiceCollection services)
        {
            services.AddLogging(option =>
            {
                option.SetMinimumLevel(LogLevel.Information);
                option.AddNLog("nlog.config");
            });

            services.AddTransient<IClientStorage, ClientStorage>();
            services.AddTransient<IComponentStorage, ComponentStorage>();
            services.AddTransient<IOrderStorage, OrderStorage>();
            services.AddTransient<IImplementerStorage, ImplementerStorage>();
            services.AddTransient<IRepairStorage, RepairStorage>();

            services.AddTransient<IClientLogic, ClientLogic>();
            services.AddTransient<IComponentLogic, ComponentLogic>();
            services.AddTransient<IOrderLogic, OrderLogic>();
            services.AddTransient<IImplementerLogic, ImplementerLogic>();
            services.AddTransient<IRepairLogic, RepairLogic>();
            services.AddTransient<IReportLogic, ReportLogic>();
            services.AddTransient<IWorkProcess, WorkModeling>();

            services.AddTransient<AbstractSaveToExcel, SaveToExcel>();
            services.AddTransient<AbstractSaveToWord, SaveToWord>();
            services.AddTransient<AbstractSaveToPdf, SaveToPdf>();

            services.AddTransient<FormMain>();
            services.AddTransient<FormClients>();
            services.AddTransient<FormComponent>();
            services.AddTransient<FormComponents>();
            services.AddTransient<FormCreateOrder>();
            services.AddTransient<FormRepair>();
            services.AddTransient<FormRepairComponent>();
            services.AddTransient<FormRepairs>();
            services.AddTransient<FormReportRepairComponents>();
            services.AddTransient<FormReportOrders>();
            services.AddTransient<FormImplementer>();
            services.AddTransient<FormImplementers>();
        }
    }
}